@@ -1,4 +1,4 @@
-from .value import OrionisStdValueException
+from .standard import OrionisStdValueException
 
 __all__ = [
     "OrionisStdValueException"
